Unit ShpModuleUnit;

Interface

Uses Windows;

Const
    DllName = 'ShpModule.Dll';

Function LoadDll: Boolean;
Function ReleaseDLL: Boolean;
Function SetWindowShapeFromBitmap(Wnd: HWND; Bmp: HBITMAP; Trans: COLORREF; EraseTrans: Boolean; Scale: Integer): Boolean;
Function ResetWindowShape(Wnd: HWND): Boolean;
Function SaveWindowShapeFromBitmap(FName: PChar; Bmp: HBITMAP; Trans: COLORREF; EraseTrans: Boolean): Boolean;
Function LoadWindowShape(FName: PChar; Wnd: HWND; Scale: Integer): Boolean;

Implementation

Var
    DLLHandle: HMODULE;
    proc_SetWindow: Function(Wnd: HWND; Bmp: HBITMAP; Trans: COLORREF; EraseTrans: Boolean; Scale: Integer): Boolean; STDCALL;
    proc_ResetWindow: Function(Wnd: HWND): Boolean; STDCALL;
    proc_SaveShape: Function(FName: PChar; Bmp: HBITMAP; Trans: COLORREF; EraseTrans: Boolean): Boolean; STDCALL;
    proc_LoadShape: Function(FName: PChar; Wnd: HWND; Scale: Integer): Boolean; STDCALL;

Function LoadDll: Boolean;
Begin
    Result := False;

    DLLHandle := 0;
    DLLHandle := LoadLibrary(DllName);
    if DLLHandle = 0 then Exit;

    proc_SetWindow := GetProcAddress(DLLHandle, 'SetWindowShapeFromBitmap');
    proc_ResetWindow := GetProcAddress(DLLHandle, 'ResetWindowShape');
    proc_SaveShape := GetProcAddress(DLLHandle, 'SaveWindowShapeFromBitmap');
    proc_LoadShape := GetProcAddress(DLLHandle, 'LoadWindowShape');

    Result := True;
End;

Function ReleaseDLL: Boolean;
Begin
    Result := True;
    if DLLHandle = 0 then Exit;

    Result := FreeLibrary(DLLHandle);
    if not Result then Exit;
    
    DLLHandle := 0;

    proc_SetWindow := Nil;
    proc_ResetWindow := Nil;
    proc_SaveShape := Nil;
    proc_LoadShape := Nil;
End;

Function SetWindowShapeFromBitmap(Wnd: HWND; Bmp: HBITMAP; Trans: COLORREF; EraseTrans: Boolean; Scale: Integer): Boolean;
Begin
    Result := False;
    If DLLHandle = 0 Then Exit;

    Result := proc_SetWindow(Wnd, Bmp, Trans, EraseTrans, Scale);
End;

Function ResetWindowShape(Wnd: HWND): Boolean;
Begin
    Result := False;
    If DLLHandle = 0 Then Exit;

    Result := proc_ResetWindow(Wnd);
End;

Function SaveWindowShapeFromBitmap(FName: PChar; Bmp: HBITMAP; Trans: COLORREF; EraseTrans: Boolean): Boolean;
Begin
    Result := False;
    If DLLHandle = 0 Then Exit;

    Result := proc_SaveShape(FName, Bmp, Trans, EraseTrans);
End;

Function LoadWindowShape(FName: PChar; Wnd: HWND; Scale: Integer): Boolean;
Begin
    Result := False;
    If DLLHandle = 0 Then Exit;

    Result := proc_LoadShape(FName, Wnd, Scale);
End;


End.


